#
# spec file for package perl-Alien-Build
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Alien-Build
Name:           perl-Alien-Build
Version:        2.80
Release:        1.7
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Build external dependencies for use in CPAN
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PL/PLICEASE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Capture::Tiny) >= 0.17
BuildRequires:  perl(Digest::SHA)
BuildRequires:  perl(ExtUtils::CBuilder)
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.64
BuildRequires:  perl(ExtUtils::ParseXS) >= 3.30
BuildRequires:  perl(FFI::CheckLib) >= 0.11
BuildRequires:  perl(File::Which) >= 1.10
BuildRequires:  perl(File::chdir)
BuildRequires:  perl(JSON::PP)
BuildRequires:  perl(List::Util) >= 1.33
BuildRequires:  perl(Path::Tiny) >= 0.077
BuildRequires:  perl(Test2::API) >= 1.302096
BuildRequires:  perl(Test2::V0) >= 0.000121
BuildRequires:  perl(Text::ParseWords) >= 3.26
BuildRequires:  perl(parent)
Requires:       perl(Capture::Tiny) >= 0.17
Requires:       perl(Digest::SHA)
Requires:       perl(ExtUtils::CBuilder)
Requires:       perl(ExtUtils::MakeMaker) >= 6.64
Requires:       perl(ExtUtils::ParseXS) >= 3.30
Requires:       perl(FFI::CheckLib) >= 0.11
Requires:       perl(File::Which) >= 1.10
Requires:       perl(File::chdir)
Requires:       perl(JSON::PP)
Requires:       perl(List::Util) >= 1.33
Requires:       perl(Path::Tiny) >= 0.077
Requires:       perl(Test2::API) >= 1.302096
Requires:       perl(Text::ParseWords) >= 3.26
Requires:       perl(parent)
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  pkg-config
# MANUAL END

%description
This module provides tools for building external (non-CPAN) dependencies
for CPAN. It is mainly designed to be used at install time of a CPAN
client, and work closely with Alien::Base which is used at runtime.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes Changes.Alien-Base Changes.Alien-Base-Wrapper Changes.Alien-Build-Decode-Mojo Changes.Test-Alien example README SUPPORT
%license LICENSE

%changelog
* Sat May 13 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.80
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.80      2023-05-11 16:31:46 -0600
  - Documentation improvements (gh#399, gh#400, gh#401, gh#402)
  - Do not generate .../Install/Files.pm if one is provided by the
    Alien (gh#393, gh#397)
  2.79      2023-05-05 15:08:46 -0600
  - Updated non-binding support for Perls to match the policy
    of the Perl toolchain (Perls older than 10 years old are
    unsupported, with a one-time exception of Perl 5.16).  The
    intent is not to suddenly drop support for older Perls, but
    the Alien-Build team may take advantage of features in
    supported Perls that will effectively remove compatability
    with unsupported Perls.
* Wed Mar  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.78
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.78      2023-03-07 11:49:27 -0700
  - Test fix to handle Perls with space in the path (gh#391, mohawk++)
* Sat Jan 21 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.77
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.77      2023-01-20 14:59:14 +1100
  - Documentation improvements (gh#389, #gh#390)
  - Additional noisy diagnostic when trying to use the regular
    download negotiator plugin with a GitHub releases page
    (gh#388, gh#390)
* Thu Dec 29 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.76
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.76      2022-12-28 18:30:39 -0700
  - Fix inline_auto_include so that it gives priority to
    the .runtime.inline_auto_include property
  2.75      2022-12-21 21:03:27 -0700
  - The Download::Negotiate plugin will no longer pick the
    Fetch::CurlCommand plugin (unless bootstrap_ssl option is
    chosen), because it relies on the -J option which is
    unfortunately not reliable.  When a more reliable method
    can be used by Fetch::CurlCommand we will likely go back
    to preferring it (gh#384, gh#385)
* Mon Nov 28 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.74
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.74      2022-11-27 08:26:06 -0700
  - Patches to Test::Alien to make it safe for C99
    (gh#383, Florian Weimer++)
* Mon Nov 21 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.73
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.73      2022-11-20 07:23:46 -0700
  - Fix Extract::ArchiveZip test when ALIEN_DOWNLOAD_RULE set to
    digest_or_encrypt (gh#382)
* Thu Oct 27 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.72
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.72      2022-10-26 06:28:00 -0600
  - Improved diagnostic when all links are excluded by the filter
    stage (gh#380)
* Wed Oct  5 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.71
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.71      2022-10-04 11:18:14 -0600
  - Added Alien::Build::Plugin::Extract::File (gh#375)
* Sat Sep 24 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.70
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.70      2022-09-23 06:27:39 -0600
  2.69_01   2022-09-20 18:00:17 -0600
  - Documentation improvements (gh#370)
  - Added meta.platform.cpu.count and meta.platform.cpu.arch.name
    properties (gh#371 zmughal++)
* Tue Sep  6 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.68
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.68      2022-09-05 09:05:18 -0600
  - Documentation improvements (gh#367)
  - alien_diag from Test::Alien::Diag now can optionaly take a
    hash reference as its last argument (gh#365, gh#366)
  - alien_diag supports two new options properties and
    list_properties (gh#365, gh#366)
  - Document that alien_diag may take more than one alien as
    an argument (this has always been the case, but never
    documented (gh#366)
  2.67      2022-09-03 17:07:40 -0600
  - Test::Alien::Diag should now handle undef fields more
    gracefully (gh#363, gh#364)
  2.66      2022-09-01 13:29:15 -0600
  - Validate SSL certificates for Fetch::HTTPTiny plugin if
    ALIEN_DOWNLOAD_RULE is one of encrypt, digest_or_encrypt
    or digest_and_encrypt (gh#362)
  2.65      2022-08-30 11:17:41 -0600
  - Fix POD name for Alien::Build::Manual::Security (gh#360)
  2.64      2022-08-30 10:09:42 -0600
  - Production release identical to 2.63.01
  - !!! Notice of Change of Behavior !!!
    In the near future, AB will require by default one of:
    1. Secure https connection
    2. Bundled pacakge (ie file:// URL)
    3. Cryptographic signature
    before extracting archives fetched off the internet.  You can test
    the new behavior yourself by setting
    ALIEN_DOWNLOAD_RULE to `digest_or_encrypt`.  More details can
    be found in the Alien::Build::Manual::Security POD
    !!! Notice of Change of Behavior !!!
  2.63_01   2022-08-30 00:44:54 -0600
  - New documentation Alien::Build::Manual::Security (gh#357)
  - Compute $build->donwload_rule as soon as possible (gh#190, gh#358)
  - ALIEN_DOWNLOAD_RULE=default is now a legal value.  It is currently
    the same as 'warn' but will probably become 'digest_or_encrypt' in
    the future (gh#356)
  - Added notice in change of behavior (gh#190, gh#359)
  2.62_01   2022-08-29 15:03:53 -0600
  - Fixed bug introduced in 2.60_01 where file URLs were not considered
    safe (gh#351, gh#355)
  2.61_01   2022-08-28 15:49:06 -0600
  - Added preload_plugin and postload_plugin to Alien::Build::rc
    (gh#348, gh#349)
  2.60_01   2022-08-28 10:37:01 -0600
  - Documentation improvements (gh#333, gh#334, gh#342, gh#343, gh#344)
  - Fixed a number of broken links in POD (gh#344)
  - Added download_detail install property (gh#190, gh#344)
  - Added download_rule method (gh#190, gh#344)
  - The fetch hook and other plugins that use the same file hash can
    and now should include a protocol field (gh#190, gh#344)
* Wed Aug 17 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.59
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.59      2022-08-16 09:38:14 -0600
  - Documentation improvements (gh#337, gh#341)
  - Do not allow downgrading from SSL if start_url is https.  This is
    done by filtering non-SSL URLs from the candidate listif the start_url
    uses https (gh#190, gh#339)
  2.58_01   2022-08-15 12:55:07 -0600
  - Fix bug where properties could not be interpolated in environment
    variables if meta.env_interpolate is on (gh#333)
  - Can now pass an Alien::Build instance into Alien::Build::Interpolator's
    interpolate method to use meta, install, runtime, etc. prroperites in
    the template (gh#312, gh#333)
  2.57_01   2022-08-15 11:09:52 -0600
  - Added experimental plugin Digest::SHA and Digest::SHAPP for checking
    signatures (gh#332)
  - Added experimental check_digest method on Alien::Build (gh#332)
  - Added experimental digest keyword for alienfile (gh#332)
  - Removed long deprecated subplugin method from Alien::Build::Plugin (gh#331)
* Sun Aug 14 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.56
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.56      2022-08-13 15:33:18 -0600
  - Production release identical to 2.55.01
  2.55_01   2022-08-13 15:28:00 -0600
  - Documentation improvements (gh#313, gh#330)
  2.54_01   2022-08-13 11:29:15 -0600
  - Documentation improvements (gh#48, gh#313, gh#329)
  2.53      2022-08-12 14:02:31 -0600
  - Documentation improvements (gh#241, gh#254, gh#283, gh#298, gh#312, gh#327)
  - Added .runtime.inline_auto_include property (gh#226, gh#328)
  - xs_ok in Test::Alien will now keep temporary generated files on failure
    by default.  You can override this behavior using TEST_ALIEN_ALWAYS_KEEP
    (gh#315, gh#326)
  - Added TEST_ALIEN_ALIENS_MISSING environment variable to remove warning
    in Test::Alien when you use some tools without first calling alien_ok
    (gh#326)
  2.52      2022-08-11 15:18:46 -0600
  - Improved documentation (gh#317, gh#318)
  - Fixed bug for run_ok in Test::Alien where passing a command in scalar
    context would not work for commands with arguments (gh#320)
  - Added interpolate_run_ok and plugin_ok to Test::Alien (gh#319, gh#321, gh#322)
  - Better support for Alien::MSYS + Test::Alien (gh#323)
  - Better handle it when flags are undef by not passing into
    Text::ParseWords::shellwords(gh#314, gh#324)
  2.51      2022-08-03 09:57:08 -0600
  - Remove use of duplicate lddlfalgs in Test::Alien which could cause failures
    on AIX (gh#217, gh#316)
* Fri Jun 24 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.50
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.50      2022-06-23 11:53:00 -0500
  - Documentation updates (gh#308, gh#310)
  2.49      2022-06-23 11:19:08 -0500
  - Fix tests to pass on systems that do not have a compiler (gh#309)
* Mon Mar 14 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.48
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.48      2022-03-13 11:20:19 -0600
  - Added atleast_version to Probe::CommandLine and Probe::CBuilder plugins
    (gh#299, gh#300, shawnlaffan++)
  - Added Alien::Util module (gh#301)
* Tue Mar  8 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.47
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.47      2022-03-07 07:03:52 -0700
  - Fixed bug where Probe::CBuilder plugin could report the wrong diagnostic
    when throwing an exception (gh#296, gh#297, shawnlaffan++)
* Wed Dec  1 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.46
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.46      2021-11-30 15:17:58 -0700
  - Fix bug where the Build::Copy plugin could fail when spaces are in
    the target path (gh#290, gh#292 kiwiroy++)
* Fri Oct 29 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.45
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.45      2021-10-28 04:55:28 -0600
  - On macOS / OS X the Build::Copy plugin now uses cp -pPR instead of
    cp -aR; on modern macOS this does the same thing, on very old versions
    of OS X the -a option is not recognized (gh#288)
* Thu Oct 21 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.44
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.44      2021-10-20 17:51:21 -0600
  - Fix bug in Alien::Build::Log::Abbreviate (gh#286 kiwiroy++)
  2.43_01   2021-09-30 10:10:07 -0600
  - Fix test for Decode::DirListingFtpCopy which was incorrectly testing
    Decode::DirListing (gh#285, gh#286)
* Thu Sep 30 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.42
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.42      2021-09-29 09:54:26 -0600
  - Improved documentation relating to the Alien::Base alt methods and
    the PkgConfig plugins use of pkg_name property (gh#234, gh#284)
* Wed Jun 23 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.41
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.41      2021-06-21 22:50:57 -0600
  - Documentation fixes (gh#266, gh#267)
  - Use parent instead of base in code and documentation (gh#268)
* Fri May 14 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.40
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.40      2021-05-13 06:44:37 -0600
  - Test::Alien tests will issue a diagnostic if you call them without
    alien_ok which is probably a mistake (gh#262, gh#263)
  2.39_01   2021-05-12 04:14:06 -0600
  - Add support for HTTP request headers on all appropriate core fetch plugins
    (gh#256, gh#259)
  - The fetch method on Alien::Build  now has a http_headers option
    (gh#256, gh#259)
  - Fix bug where symlinks to directories were incorrectly being skipped
    (gh#255, gh#260)
* Tue Jan 12 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.38
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.38      2021-01-11 14:35:54 -0700
  - Fixed a bug the can cause an array dereference error in pkg-config command line
    plugin on MSYS2 / MinGW environment (gh#243)
  - Changed the auto-generated module name for Test::Alien, in a way that works
    around a probable bug / issue with ExtUtils::CBuilder (gh#243)
* Tue Nov  3 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.37
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.37      2020-11-02 09:09:13 -0700
  - Tests that rely on its behavior unset ALIEN_BUILD_PKG_CONFIG (gh#239)
  2.36_01   2020-10-31 03:33:21 -0600
  - Fixed a bug where Probe and PkgConfig plugins could provide compiler / linker flags
    when the PkgConfig probe fails, but another probe succeed. (gh#238)
  2.35_01   2020-10-28 02:06:21 -0600
  - Added install properties: system_probe_class and system_probe_instance_id (gh#237)
  - Added hook properties: probe_class and probe_instance_id (gh#237)
  2.34_01   2020-10-27 04:23:24 -0600
  - Added instance_id property to Alien::Build::Plugin class (gh#235)
  - Added plugin_instance_prop method to Alien::Build class (gh#235)
* Tue Sep 22 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.33
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.33      2020-09-21 03:21:40 -0600
  - Skip problematic test on cygwin (gh#232)
* Sat Sep 12 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.32
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.32      2020-09-11 10:42:41 -0600
  - Production release identical to 2.27_01
  2.31_01   2020-09-09 06:26:25 -0600
  - Diagnostic release
  2.30_01   2020-09-08 14:48:12 -0600
  - Documentation fixes (gh#223, #224, #225, shawnlaffan++)
  - Use shorter filename paths for test files to keep older versions of tar
    happy (gh#228, gh#229, gh#230)
* Tue Aug 11 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.29
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.29      2020-08-10 09:16:59 -0600
  - Move to new GitHub org: https://github.com/PerlAlien
  - Fixed meta which was incorrectly requiring 5.8.1 instead of 5.8.4
* Thu Aug  6 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.28
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.28      2020-08-04 21:33:19 -0600
  - Production release identical to 2.27_01
  2.27_01   2020-08-03 13:47:02 -0600
  - Some fixes for the unofficial `msys` fork of Perl (gh#211, gh#212)
  - Honour user supplied `config.site` for autoconf (gh#215, gh#218, hakonhagland++)
  - Hard drop of support for Perl 5.8.1, 5.8.2 and 5.8.3.  AB will refuse to install
    on these elder Perls.  Please upgrade to at least 5.8.4.  (gh#200, gh#201, gh#219)
* Wed Jun 17 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.26
  see /usr/share/doc/packages/perl-Alien-Build/Changes.Alien-Base-Wrapper
  2.26      2020-06-16 07:11:13 -0600
  - Diagnostic release
  2.25      2020-06-10 09:18:25 -0600
  - Fixed bug where alien library directory flags could be used in the wrong
    order by Test::Alien, mostly a problem on NetBSD and similar platforms
    (gh#203)
  2.24_01   2020-06-07 18:13:55 -0600
  - Disable parallel build when clean install is enabled
    (gh#197, gh#198, shawnlaffan++)
  - Dropping support for Perl 5.8.1, 5.8.2 and 5.8.3.  For now AB will install
    on these versions of Perl, but a warning will be issued, along with a 3
    minute sleep at configure time.  Please upgrade to 5.8.4 (or preferrably
    5.32).  Starting July 1st, AB will refuse to install on these elderly Perls.
    (gh#200, gh#201)
* Sat May 16 2020 Tina Müller <timueller+perl@suse.de>
  updated to 2.23
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.23      2020-05-15 18:36:59 -0400
  - Workaround apparent bug in pkgconf + arm64 (gh#196)
* Wed May  6 2020 Tina Müller <timueller+perl@suse.de>
  updated to 2.22
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.22      2020-05-05 07:02:49 -0600
  - Added dynamic_dir method to Alien::Base (gh#191, shawnlaffan++)
* Sun Apr 12 2020 <timueller+perl@suse.de>
- updated to 2.21
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.21      2020-04-11 08:27:21 -0600
  - Fix the handling of version regular expression for the Prefer::SortVersions
    plugin to handle regular expressions with multiple capture groups (gh#189)
  2.20      2020-04-10 06:21:54 -0600
  - xs_ok does a better workaround for faux fork on cygwin (gh#153, gh#187, gh#188)
  2.19      2020-04-09 02:56:14 -0600
  - Production release identical to 2.18_01
  2.18_01   2020-04-03 10:06:45 -0600
  - Add Build::Copy plugin (gh#186)
* Sat Mar 21 2020 <timueller+perl@suse.de>
- updated to 2.17
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.17      2020-03-19 21:03:39 -0600
  - Production release identical to 2.16_01
  2.16_01   2020-03-17 13:56:13 -0600
  - Probe::Vcpkg adds include property (gh#184)
  - Build::Autoconf will now copy .dll files from bin to dynamic
    directory on MSWin32 (gh#183)
* Tue Mar 17 2020 <timueller+perl@suse.de>
- updated to 2.15
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.15      2020-03-16 06:53:31 -0600
  - Tests on Windows will use the system temp directory rather than
    a temp directory under the install directory. A temp directory
    under the install directory was used to work around typically
    Linux systems that have noexec set on /tmp.  Since this is less
    normal on Windows, and can cause mkpath errors if the install
    directory is too deep we will use the windows system temp directory.
    (gh#181, gh#182)
* Mon Mar 16 2020 <timueller+perl@suse.de>
- updated to 2.14
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.14      2020-03-15 12:49:17 -0600
  - Added ffi_name property to Probe::Vcpkg plugin (gh#179)
  - Documentation fixes (gh#180)
* Tue Mar 10 2020 <timueller+perl@suse.de>
- updated to 2.12
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.12      2020-03-09 10:02:37 -0600
  - Fixed bug where Probe::Vcpkg plugin doesn't set version probe hook
    property (gh#178)
  2.11      2020-03-09 03:04:49 -0600
  - Production release identical to 2.10
  2.10_01   2020-03-08 17:13:05 -0600
  - Probe::Vcpkg plugin defaults to name property (gh#177)
  2.09_01   2020-03-08 09:58:17 -0600
  - Added Alien::Build::Plugin::Probe::Vcpkg (gh#3, gh#175)
* Sun Feb 16 2020 <timueller+perl@suse.de>
- updated to 2.08
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.08      2020-02-15 17:16:30 -0700
  - Production release identical to 2.07_01
  2.07_01   2020-02-14 19:00:22 -0700
  - Fix Alien::Build::Interpolate bug introduced in 2.06_01 (gh#171)
  2.06_01   2020-02-14 12:23:02 -0700
  - Several helpers for Alien::Build::Interpolate::Default no longer
    require Aliens if the tools are already found in the PATH (gh#168)
  - Better document dynamic vs. static libraries in AlienAuthor and FAQ
    documents (gh#110, gh#169)
  - Prefer nmake or gmake over dmake on Windows, even if Perl is
    configured to use dmake (gh#95, gh#170)
  2.05_01   2020-02-11 15:19:01 -0700
  - Fix bug where the autoconf plugin could use the wrong configure if
    there is another "configure" script somewhere in the PATH on Windows
    (gh#166, gh#167)
* Fri Feb  7 2020 <timueller+perl@suse.de>
- updated to 2.04
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.04      2020-02-05 19:05:32 -0700
  - Production release identical to 2.03_01
  2.03_01   2020-02-04 21:29:35 -0700
  - Add use strict to generated ::Installl::Files modules (gh#162, gh#163)
* Wed Feb  5 2020 <timueller+perl@suse.de>
- updated to 2.02
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.02      2020-02-04 13:12:49 -0700
  - Production release identical to 2.01_01
  2.01_01   2020-02-03 10:51:43 -0700
  - Prefer Decode::HTML if HTML::Parser is already installed and Mojolicious
    or Mojo::DOM58 are not (gh#160)
* Mon Feb  3 2020 <timueller+perl@suse.de>
- updated to 2.00
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  2.00      2020-02-02 06:25:13 -0700
  - Production release identical to 2.00
  1.99_01   2020-01-30 12:57:33 -0700
  - Decode::Mojo plugin remembers which version of Mojo::DOM it is using (gh#159)
* Fri Jan 31 2020 <timueller+perl@suse.de>
- updated to 1.98
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.98      2020-01-30 07:53:10 -0700
  - Production release identical to 1.97_01
  1.97_01   2020-01-29 09:22:14 -0700
  - Added OO interface to Alien::Base::Wrapper (gh#157, gh#158)
  - Added mm_args2 method to Alien::Base::Wrapper (gh#157, gh#158)
  - Added WriteMakefile function to Alien::Base::Wrapper (gh#157, gh#158)
* Tue Jan 28 2020 <timueller+perl@suse.de>
- updated to 1.96
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.96      2020-01-27 09:05:36 -0700
  - Production release identical to 1.95_01
  1.95_01   2020-01-25 19:57:31 -0700
  - Reduced prereqs to Alien::Base::Wrapper down to Perl 5.6
    (the rest of Alien-Build still requires 5.8) (gh#156)
  - Remove dep on Module::Load (gh#155)
* Tue Dec 17 2019 <timueller+perl@suse.de>
- updated to 1.94
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.94      2019-12-16 12:17:26 -0700
  - Prefer tar.exe on Windows if it is bsdtar (gh#150)
  - Prefer tar.exe on Windows for unzip if it is bsdtar (gh#151, gh#152)
* Tue Dec 10 2019 <timueller+perl@suse.de>
- updated to 1.93
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.93      2019-12-09 02:22:44 -0700
  - curl plugin not used unless required -J option is supported.
    (gh#147, gh#148)
* Tue Nov 19 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Update spec file
* Tue Nov  5 2019 <timueller+perl@suse.de>
- updated to 1.92
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.92      2019-11-04 04:33:57 -0700
  - Require Test2::API 1.302096 for features used in test suite.
  1.91      2019-11-01 20:19:19 -0600
  - Fix bug where Test::Alien::Diag could crash for Aliens without
    dynamic libraries.
  1.90      2019-11-01 16:15:32 -0700
  - Added Test::Alien::Diag (gh#142)
  - Test::Alien ffi_ok add api option. (gh#143)
* Thu Sep 26 2019 <timueller+perl@suse.de>
- updated to 1.89
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.89      2019-09-25 07:58:39 -0600
  - Production release identical to 1.88_01
  1.88_01   2019-09-24 11:53:18 -0600
  - Add options cbuilder_check amd cbuilder_config to Test::Alien xs_ok
    function (gh#140, Test-Alien-CPP#3, Test-Alien-CPP#4)
  1.87_01   2019-09-24 07:38:31 -0600
  - Test::Alien directive with_subtest will attempt to catch SEGV and bail
    on on test file with a helpful diagnostic.  The prove util frequently
    does not provide a useful diagnostic for SEGV on its own (gh#138, gh#139).
* Mon Sep 16 2019 <timueller+perl@suse.de>
- updated to 1.86
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.86      2019-09-13 06:27:21 -0600
  - PAUSE permission fix
* Sat Aug 31 2019 <timueller+perl@suse.de>
- updated to 1.85
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.85      2019-08-30 14:19:16 -0400
  - Production release identical to 1.84_01
  1.84_01   2019-08-26 10:59:58 -0400
  - Delay removal of temp files for Test::Alien till `make clean` instead of
    test termination on Windows (only) to avoid warning on test termination.
    (gh#130, gh#136)
* Tue Aug 20 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.83
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.83      2019-08-19 18:31:19 -0400
  - Production release identical to 1.81_01
  1.82_01   2019-08-18 19:47:10 -0400
  - Stricter Perl::Critic policies (gh#135)
  1.81_01   2019-08-16 19:16:33 -0400
  - Fix log class inheritence bug.
  1.80_01   2019-08-15 20:52:50 -0400
  - Use Perl::Critic Freenode policies for development (gh#128)
  - Add new configurable log class (gh#123)
* Tue Jul 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.79
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.79      2019-07-15 14:26:16 -0400
  - Fix CBuilder probe plugin on platforms where /tmp is mounted noexec (gh#133, gh#134)
* Mon Jul  1 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.78
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.78      2019-06-30 21:31:23 -0400
  - Production release identical to 1.77_01
  1.77_01   2019-06-28 12:08:12 -0400
  - _alien/alien.json file is generated using ->canonical(1) for reproducibility
    (gh#132 Grinnz++ for the suggestion)
  - _alien/alien.json file is generated using ->ascii to avoid warnings / errors
    when unicode is included in install/runtime properties.
    (gh#132 Grinnz++ for the suggestion)
* Mon Jun 24 2019 Stephan Kulow <coolo@please-enter-an-email-address>
- updated to 1.76
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.76      2019-06-23 11:01:08 -0400
  - Production release identical to 1.75_01
  1.75_01   2019-06-07 15:06:30 -0400
  - Download::Negotiate defaults to Deocde::Mojo instead of Decode::HTML for
    share installs that require parsing an HTML index (gh#127, gh#115).
* Fri May 24 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.74
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.74      2019-05-22 08:43:10 -0400
  - Check if share directory exists before clean_install
    (gh#114, gh#126 zmughal++ for the report)
* Tue May 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.73
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.73      2019-05-20 14:49:10 -0400
  - Production release identical to 1.72_01
  1.72_01   2019-05-11 04:12:13 -0600
  - Merged Alien-Build-Plugin-Decode-Mojo into this dist (gh#18)
  - Put Alien -l flags first in xs_ok (gh#121 kiwiroy++)
  1.71_01   2019-04-30 05:41:40 -0400
  - Add clean_install hook (gh#111, gh#114)
  - EXPERIMENTAL Add mm_install method to Alien::Build::MM (gh#111, gh#114)
  - EXPERIMENTAL CAUTION Add alien_clean_install target to Makefile generated
    by Alien::Build::MM (gh#111, gh#114)
  1.70_01   2019-04-29 18:57:53 -0400
  - Add alien_clean target for Alien::Build::MM (gh#118, gh#119)
* Sun Apr 28 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.69
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.69      2019-04-27 10:59:10 -0400
  - Add runtime property ffi_checklib (gh#117)
    Related to https://github.com/Perl5-FFI/FFI-CheckLib/issues/13
  1.68      2019-04-23 04:57:49 -0400
  - Add decoder property to Download::Negotiate plugin (gh#115, gh#116)
* Tue Apr 23 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.67
  see /usr/share/doc/packages/perl-Alien-Build/Changes.Alien-Base-Wrapper
* Fri Apr 12 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.65
  see /usr/share/doc/packages/perl-Alien-Build/Changes.Alien-Base-Wrapper
* Tue Apr  9 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.63
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.63      2019-04-08 17:19:03 -0400
  - Documentation improvements
  - Fixed bug in Test::Alien::Build alienfile_skip_if_missing_prereqs
    where subtest / test was always skipped regardless of requirements.
    It now (correctly) only skips if there are missing requirements.
* Sat Mar 30 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.62
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.62      2019-03-27 11:34:00 -0400
  - Production release identical to 1.61_01
  1.61_01   2019-03-25 15:35:06 -0400
  - Add hook property `version` for probe hook (gh#99, gh#100).
  - Improvements for Fetch CurlCommand plugin (gh#101).
* Wed Mar 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.60
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.60      2019-03-01 03:16:23 -0500
  - Documentation improvemens.  (gh#50, gh#84).
  1.59_01   2019-02-27 21:40:24 -0500
  - Fix test fail for download negotiation plugin introduced in 1.58_01
    which was expressed on systems without curl installed.
  1.58_01   2019-02-27 12:50:20 -0500
  - Prefer Fetch::CurlCommand over Fetch::HTTPTiny for https when:
  * Net::SSLeay and IO::Socket::SSL are not installed
  * AND curl is installed
  * AND curl supports https
    This makes AB more reliable on platforms like OS X when openssl
    is broken without a third party package system like homebrew,
    and on older Perls like 5.8.x where Net::SSLeay frequently does
    not install or pass tests.
    The existing behavior of prefer Fetch::HTTPTiny when:
  * Net::SSLeay and IO::Socket::SSL are already installed
  * OR the URL is http
  * OR curl is not already installed
    is still in effect. (gh#93, gh#94)
  1.57_01   2019-02-26 08:52:34 -0500
  - Test unzip command before blindly using it (tests were already
    being made for tarballs) (gh#90)
  1.56_01   2019-02-24 14:09:23 -0500
  - Prefer Alien::unzip over Archive::Zip.  The latter turns out to be broken
    on one platform or another for much of the time.  (gh#74, gh#89).
* Mon Feb 25 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.55
  see /usr/share/doc/packages/perl-Alien-Build/Changes.Alien-Base-Wrapper
* Sun Feb 10 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.52
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.52      2019-02-09 05:45:12 -0500
  - Use $alien->libs -L flags to help find system dynamic libs.
* Sun Jan 20 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.51
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.51      2019-01-19 14:23:23 -0500
  - cmake plugin sets CMAKE_INSTALL_LIBDIR:PATH to lib for share installs
    for cmake projects using GNUInstallDirs on platforms that default to
    something other than lib.
* Thu Jan 17 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.50
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.50      2019-01-16 12:55:08 -0500
  - Removed temp testing files unintentionally included in the previous
    release.
  - Require ExtUtils::MakeMaker 6.64, for Alien::Build::MM, which can
    sometimes have its BUILD_REQUIRES or TEST_REQUIRES overridden by
    Dist::Zilla otherwise.
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.49
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.49      2018-11-04 15:22:40 -0500
  - Added Alien::Build::Plugin::Test::Mock
  - Added alienfile_skip_if_missing_prereqs function to Test::Alien::Build
  - Remove run-time dependency on Test2::Suite
    Test2::API is still a run-time dependency, but that has
    been in-core since 5.26.
* Fri Jul  6 2018 coolo@suse.com
- updated to 1.48
  see /usr/share/doc/packages/perl-Alien-Build/Changes
* Tue Jun 26 2018 coolo@suse.com
- updated to 1.46
  see /usr/share/doc/packages/perl-Alien-Build/Changes
* Mon Jun  4 2018 coolo@suse.com
- updated to 1.43
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.43      2018-06-03 06:41:28 -0400
  - Documentation fixes
  - Use a custom site.config to ensure libraries are installed in lib
    and not lib64 or lib/64 for share installs
* Thu May 10 2018 coolo@suse.com
- updated to 1.42
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.42      2018-05-09 08:19:18 -0400
  - Corrected typo for install_prop->{old}->{prefix} (had been preifx)
* Wed Apr 25 2018 coolo@suse.com
- updated to 1.41
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.41      2018-04-24 06:19:18 -0400
  - before and after directives in alienfile triggers requirement on Alien::Build 1.40
  1.40_01   2018-04-12 09:21:05 -0400
  - Add before and after directives to alienfile syntax
* Tue Apr 10 2018 coolo@suse.com
- updated to 1.39
  see /usr/share/doc/packages/perl-Alien-Build/Changes
  1.39      2018-03-09 05:51:47 -0500
  - Production release identical to 1.38_01
  1.38_01   2018-03-01 03:27:29 -0500
  - Additional testing diagnostics
  1.37      2018-02-23 10:13:44 -0500
  - Fixed cmake test which would fail without a C++ compiler (gh#53 ppisar++)
  1.36      2018-02-05 10:51:59 -0500
  - Production release identical to 1.35_01
  1.35_01   2017-12-28 12:42:56 -0500
  - Improve diagnostic in command line extraction test
  1.34_01   2017-12-27 10:30:10 -0500
  - Add env_interpolate meta property.
  - PkgConfig plugins now attempt to set PKG_CONFIG environment variable during build
  1.33_01   2017-11-08 11:54:19 -0500
  - Improve diagnostic for partially installed Alien error
  1.32      2017-11-03 13:15:35 -0400
  - Add ALIEN_INSTALL_NETWORK environment variable.  Set to false if you don't
    want to allow network fetch.
  1.31_01   2017-10-31 16:50:52 -0400
  - Fix testing prereq bug introduced in 1.30_01.
  1.30_01   2017-10-31 14:24:15 -0400
  - Add prefer property to Download::Negotiate plugin
  1.29_01   2017-10-30 09:54:22 -0400
  - Fix bug in Alien::Base::Wrapper where -l flags were being ignored by EUMM
  - MSYS plugin works with ffi build
  - Windows specific fixes for Alien::Base::Wrapper
  - Removed optional dependency on Test::Exec
  1.28      2017-10-29 19:39:19 -0400
  - Production release identical to 1.27_01
  1.27_01   2017-10-27 10:26:18 -0400
  - Fix incompatibility with older versions of ExtUtils::MakeMaker where test
    directive in alienfile was ignored.
  1.26_01   2017-10-25 12:28:58 -0400
  - Fix Test::Alien bug where -L could be placed after directories specified in %%Config
    (this was already handled correctly by Alien::Base::Wrapper).
  - Remove cpp and C++ options for xs_ok (I don't believe these were used in practice
    and were issuing deprecation warnings for a while).
  - A number of documentation errors have been fixed (jjatria++ leto++)
* Tue Oct 10 2017 coolo@suse.com
- initial package 1.25
  * created by cpanspec 1.78.08
